@@ -36,6 +36,7 @@ export int db_data_subdirs = 0;	/* set if DATA/[0-9]/ exist	 */
 export char *news_active;	/* NLIB/active or DB/ACTIVE */
 
 export char *pager;
+export char *organization;
 
 export char *log_file;			/* = lib/Log */
 export char *log_entry_filter = NULL;
@@ -302,6 +303,8 @@ init_global()
     if(!nn_directory) /* if not set on command line */
 	nn_directory = mk_file_name(home_directory, ".nn");
 
+    organization = getenv("ORGANIZATION");
+
     return 0;
 }
 
