@@ -157,7 +157,7 @@ static int nn_locked()
     if (proto_lock(I_AM_NN, PL_SET)) {
 	
 	if (proto_host[0])
-	    nn_exitmsg(1, "\nnn is running on host %s\nor %s/LOCK should be removed.\n\n", nn_directory, proto_host);
+	    nn_exitmsg(1, "\nnn is running on host %s\nor %s/LOCK should be removed.\n\n", proto_host, nn_directory);
 	else
 	    nn_exitmsg(1, "\nAnother nn process is already running\n\n");
     }
@@ -864,7 +864,8 @@ char *argv[];
 	nn_exitmsg(1, "%s: nn has not been invoked to initialize user files", pname);
 
 #ifdef NNTP
-    nntp_check();
+    if (who_am_i != I_AM_VIEW)
+	nntp_check();
 #endif
 
     init_key_map();
