@@ -98,18 +98,6 @@ export int nntp_debug = 0;
 import char *home_directory;
 import int silent, no_update;
 
-#ifndef __FreeBSD__
-#ifndef __NetBSD__
-#ifndef __linux__
-extern int sys_nerr;
-extern char *sys_errlist[];
-#endif	/* __linux__ */
-#endif	/* __NetBSD__ */
-#endif	/* __FreeBSD__ */
-
-#define syserr() (errno >= 0 && errno < sys_nerr ? \
-		  sys_errlist[errno] : "Unknown error.")
-
 import char *mktemp();
 
 static FILE *nntp_in = NULL;		/* fp for reading from server */
@@ -331,7 +319,7 @@ get_socket()
 	if (x == 0)
 	    break;
 	if (who_am_i != I_AM_MASTER)
-	    msg("Connecting to %s failed: %s", nntp_server, syserr());
+	    msg("Connecting to %s failed: %s", nntp_server, strerror(errno));
 	(void) close(s);
 	s = -1;
     }
@@ -373,13 +361,13 @@ get_socket()
     return -1;
 
  sock_err:
-    sys_warning("Can't get NNTP socket: %s", syserr());
+    sys_warning("Can't get NNTP socket: %s", strerror(errno));
     return -1;
 
  conn_err:
     (void) close(s);
     if (who_am_i == I_AM_MASTER)
-	sys_warning("Connecting to %s failed: %s", nntp_server, syserr());
+	sys_warning("Connecting to %s failed: %s", nntp_server, strerror(errno));
     return -1;
 }
 
@@ -449,7 +437,7 @@ connect_server()
 	    can_post = 0;
 	    break;
 	default:
-	    nn_exitmsg(1, line);
+	    nn_exitmsg(1, "%s", line);
 	    /* NOTREACHED */
 	}
     }
@@ -535,8 +523,9 @@ reconnect_server(int retry)
 	    nn_exitmsg(1, "failed to reconnect to server");
     }
 
-    if (nntp_set_group(group_hd) < 1)
-	nn_exitmsg(1, "unable to set group");
+    if (group_hd)
+	if (nntp_set_group(group_hd) < 1)
+	    nn_exitmsg(1, "unable to set group");
 
     if (nntp_debug)
 	debug_msg(" Resend last command", buf);
@@ -803,7 +792,7 @@ nntp_check()
 {
     char *server_real_name = NULL;
     struct hostent *hp;
-#ifndef DOMAIN
+#if !defined(DOMAIN) || !defined(HIDDENNET)
     char *cp;
 #endif
 
